# Generated by Django 3.1.5 on 2021-04-03 05:58

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Artist',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=50)),
                ('description', models.TextField()),
                ('instagram', models.CharField(max_length=50)),
                ('telephone', models.CharField(max_length=10)),
                ('picture', models.ImageField(upload_to='artist')),
            ],
        ),
        migrations.CreateModel(
            name='Collection',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('artist', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='flashday.artist')),
            ],
        ),
        migrations.CreateModel(
            name='Event',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=50)),
                ('description', models.TextField()),
                ('image', models.ImageField(upload_to='product')),
            ],
        ),
        migrations.CreateModel(
            name='Product',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=50)),
                ('description', models.TextField()),
                ('picture', models.ImageField(upload_to='product')),
                ('collection', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='flashday.collection')),
            ],
        ),
        migrations.CreateModel(
            name='ProductOption',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('value', models.CharField(max_length=50)),
                ('reference', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='flashday.product')),
            ],
        ),
        migrations.CreateModel(
            name='ExtraPicture',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('image', models.ImageField(upload_to='product')),
                ('reference', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='flashday.product')),
            ],
        ),
    ]



from django.http import JsonResponse
from django.shortcuts import render
from django.views import View

from .models import *


class Home(View):
    def get(self, request):
        return JsonResponse({
            'event': Event.objects.count(),
            'artist': Artist.objects.count(),
            'collection': Collection.objects.count(),
            'product': Product.objects.count(),
        })



from django.db.models import (
    CASCADE,
    BooleanField,
    CharField,
    ForeignKey,
    ImageField,
    Model,
    TextField,
)


class Event(Model):
    title = CharField(max_length=50)
    description = TextField()
    image = ImageField(upload_to='event')

    def __str__(self):
        return self.title


class Artist(Model):
    name = CharField(max_length=50)
    description = TextField()
    instagram = CharField(max_length=50)
    telephone = CharField(max_length=13)
    picture = ImageField(upload_to='artist')

    def __str__(self):
        return self.name


class Collection(Model):
    artist = ForeignKey(Artist, on_delete=CASCADE)

    def __str__(self):
        return self.artist.name


class Product(Model):
    collection = ForeignKey(Collection, on_delete=CASCADE)
    title = CharField(max_length=50)
    description = TextField()
    availability = BooleanField(default=True)
    picture = ImageField(upload_to='product')

    def __str__(self):
        return self.title


class ProductOption(Model):
    reference = ForeignKey(Product, on_delete=CASCADE)
    key = CharField(max_length=50)
    value = CharField(max_length=50)

    def __str__(self):
        return self.key


class ExtraPicture(Model):
    reference = ForeignKey(Product, on_delete=CASCADE)
    image = ImageField(upload_to='product')

    def __str__(self):
        return self.image.name

